nrf-pac

Crates

0.4.0

Versions

nrf52840

Flavors

Saadc

Struct Saadc 

pub struct Saadc { /* private fields */ }
Successive approximation register (SAR) analog-to-digital converter.

Implementations

Source

impl Saadc

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn tasks_start(self) -> Reg<u32, W>

Starts the SAADC and prepares the result buffer in RAM.

pub const fn tasks_sample(self) -> Reg<u32, W>

Takes one SAADC sample.

pub const fn tasks_stop(self) -> Reg<u32, W>

Stops the SAADC and terminates all on-going conversions.

pub const fn tasks_calibrateoffset(self) -> Reg<u32, W>

Starts offset auto-calibration.

pub const fn events_started(self) -> Reg<u32, RW>

The SAADC has started.

pub const fn events_end(self) -> Reg<u32, RW>

The SAADC has filled up the result buffer.

pub const fn events_done(self) -> Reg<u32, RW>

A conversion task has been completed. Depending on the configuration, multiple conversions might be needed for a result to be transferred to RAM.

pub const fn events_resultdone(self) -> Reg<u32, RW>

Result ready for transfer to RAM.

pub const fn events_calibratedone(self) -> Reg<u32, RW>

Calibration is complete.

pub const fn events_stopped(self) -> Reg<u32, RW>

The SAADC has stopped.

pub const fn events_ch(self, n: usize) -> EventsCh

Peripheral events.

pub const fn inten(self) -> Reg<Int, RW>

Enable or disable interrupt.

pub const fn intenset(self) -> Reg<Int, RW>

Enable interrupt.

pub const fn intenclr(self) -> Reg<Int, RW>

Disable interrupt.

pub const fn status(self) -> Reg<Status, R>

Status.

pub const fn enable(self) -> Reg<Enable, RW>

Enable or disable SAADC.

pub const fn ch(self, n: usize) -> Ch

Unspecified.

pub const fn resolution(self) -> Reg<Resolution, RW>

Resolution configuration.

pub const fn oversample(self) -> Reg<Oversample, RW>

Oversampling configuration. The RESOLUTION is applied before averaging, thus for high OVERSAMPLE a higher RESOLUTION should be used.

pub const fn samplerate(self) -> Reg<Samplerate, RW>

Controls normal or continuous sample rate.

pub const fn result(self) -> Result

RESULT EasyDMA channel.